@@ -1,11 +1,11 @@
 """The sensor resource."""
 
 from __future__ import unicode_literals
-from . import Resource
+from . import Device
 from . import timeseries, metadata
 
 
 @timeseries()
 @metadata()
-class Sensor(Resource):
+class Sensor(Device):
     pass
